![Logo](/docs/SVG/logo-transparent.svg)

<p align="center">
    <img alt="Framework Version" src="https://img.shields.io/badge/Latest_version-v0.1.0b4-A04?style=flat-square">
    <img alt="Python Version" src="https://img.shields.io/badge/Python-3.12-purple?style=flat-square">
    <img alt="PyPi" src="https://img.shields.io/pypi/v/twilight_vk?color=04A&label=PyPI&style=flat-square">
    <img alt="Issues" src="https://img.shields.io/github/issues/darky-bot/TwilightVK?style=flat-square">
</pg>

## TwilightVK

TwilightVK - это асинхронный фреймворк для удобного взаимодействия с VK API и быстрой разработки ботов и приложений разной сложности.

## Руководство

Вы можете ознакомиться с тем, как использовать данный фреймворк, прочитав документацию ниже
+ [Содержание](/docs/content.md)

## Почему TwilightVK?

Основная цель данного фреймворка - обеспечить удобство разработки и управления, за счёт широкого набора инструментов, возможностей его самостоятельного и легкого расширения и встроенной поддержки API эндпоинтов для работы с ботом через админ-панель в браузере.
> NOTE: TwilightVK является личным экспериментом и не обязывает вас сравнивать его с другими фреймворками. У него, как и у других, есть свои плюсы и минусы.

## Установка

#### Последняя стабильная версия
Установить стабильную версию фреймворка можно через команду:

    pip install twilight-vk

#### Последняя актуальная версия (включая бэта-версии)
Установить актуальную версию фреймворка из GitHub можно через команду:

    pip install git+https://github.com/darky-bot/TwilightVK.git